@@ -26,6 +26,7 @@ import (
 
 	configv1 "github.com/openshift/api/config/v1"
 	configv1client "github.com/openshift/client-go/config/clientset/versioned"
+	"github.com/openshift/origin/test/e2e/upgrade/alert"
 	"github.com/openshift/origin/test/e2e/upgrade/service"
 	"github.com/openshift/origin/test/extended/util/disruption"
 	"github.com/openshift/origin/test/extended/util/disruption/controlplane"
@@ -36,6 +37,7 @@ func AllTests() []upgrades.Test {
 	return []upgrades.Test{
 		&controlplane.KubeAvailableTest{},
 		&controlplane.OpenShiftAvailableTest{},
+		&alert.UpgradeTest{},
 		&frontends.AvailableTest{},
 		&service.UpgradeTest{},
 		&upgrades.SecretUpgradeTest{},
@@ -109,36 +111,34 @@ func SetUpgradeAbortAt(policy string) error {
 	return fmt.Errorf("abort-at must be empty, set to 'random', or an integer in [0,100], inclusive")
 }
 
-var _ = g.Describe("[Disruptive]", func() {
+var _ = g.Describe("[sig-arch][Feature:ClusterUpgrade]", func() {
 	f := framework.NewDefaultFramework("cluster-upgrade")
 	f.SkipNamespaceCreation = true
 	f.SkipPrivilegedPSPBinding = true
 
-	g.Describe("Cluster upgrade", func() {
-		g.It("should maintain a functioning cluster [Feature:ClusterUpgrade]", func() {
-			config, err := framework.LoadConfig()
-			framework.ExpectNoError(err)
-			client := configv1client.NewForConfigOrDie(config)
-			dynamicClient := dynamic.NewForConfigOrDie(config)
+	g.It("Cluster should remain functional during upgrade [Disruptive]", func() {
+		config, err := framework.LoadConfig()
+		framework.ExpectNoError(err)
+		client := configv1client.NewForConfigOrDie(config)
+		dynamicClient := dynamic.NewForConfigOrDie(config)
 
-			upgCtx, err := getUpgradeContext(client, upgradeToImage)
-			framework.ExpectNoError(err, "determining what to upgrade to version=%s image=%s", "", upgradeToImage)
+		upgCtx, err := getUpgradeContext(client, upgradeToImage)
+		framework.ExpectNoError(err, "determining what to upgrade to version=%s image=%s", "", upgradeToImage)
 
-			disruption.Run(
-				"Cluster upgrade",
-				"upgrade",
-				disruption.TestData{
-					UpgradeType:    upgrades.ClusterUpgrade,
-					UpgradeContext: *upgCtx,
-				},
-				upgradeTests,
-				func() {
-					for i := 1; i < len(upgCtx.Versions); i++ {
-						framework.ExpectNoError(clusterUpgrade(client, dynamicClient, config, upgCtx.Versions[i]), fmt.Sprintf("during upgrade to %s", upgCtx.Versions[i].NodeImage))
-					}
-				},
-			)
-		})
+		disruption.Run(
+			"Cluster upgrade",
+			"upgrade",
+			disruption.TestData{
+				UpgradeType:    upgrades.ClusterUpgrade,
+				UpgradeContext: *upgCtx,
+			},
+			upgradeTests,
+			func() {
+				for i := 1; i < len(upgCtx.Versions); i++ {
+					framework.ExpectNoError(clusterUpgrade(client, dynamicClient, config, upgCtx.Versions[i]), fmt.Sprintf("during upgrade to %s", upgCtx.Versions[i].NodeImage))
+				}
+			},
+		)
 	})
 })
 
@@ -168,7 +168,7 @@ func getUpgradeContext(c configv1client.Interface, upgradeImage string) (*upgrad
 		}, nil
 	}
 
-	cv, err := c.ConfigV1().ClusterVersions().Get("version", metav1.GetOptions{})
+	cv, err := c.ConfigV1().ClusterVersions().Get(context.Background(), "version", metav1.GetOptions{})
 	if err != nil {
 		return nil, err
 	}
@@ -270,7 +270,7 @@ func clusterUpgrade(c configv1client.Interface, dc dynamic.Interface, config *re
 	}
 
 	// trigger the update
-	cv, err := c.ConfigV1().ClusterVersions().Get("version", metav1.GetOptions{})
+	cv, err := c.ConfigV1().ClusterVersions().Get(context.Background(), "version", metav1.GetOptions{})
 	if err != nil {
 		return err
 	}
@@ -282,7 +282,7 @@ func clusterUpgrade(c configv1client.Interface, dc dynamic.Interface, config *re
 		Force:   true,
 	}
 	cv.Spec.DesiredUpdate = &desired
-	updated, err := c.ConfigV1().ClusterVersions().Update(cv)
+	updated, err := c.ConfigV1().ClusterVersions().Update(context.Background(), cv, metav1.UpdateOptions{})
 	if err != nil {
 		return err
 	}
@@ -329,12 +329,12 @@ func clusterUpgrade(c configv1client.Interface, dc dynamic.Interface, config *re
 				Force: true,
 			}
 			if err := retry.RetryOnConflict(wait.Backoff{Steps: 10, Duration: time.Second}, func() error {
-				cv, err := c.ConfigV1().ClusterVersions().Get("version", metav1.GetOptions{})
+				cv, err := c.ConfigV1().ClusterVersions().Get(context.Background(), "version", metav1.GetOptions{})
 				if err != nil {
 					return err
 				}
 				cv.Spec.DesiredUpdate = &desired
-				cv, err = c.ConfigV1().ClusterVersions().Update(cv)
+				cv, err = c.ConfigV1().ClusterVersions().Update(context.Background(), cv, metav1.UpdateOptions{})
 				if err == nil {
 					updated = cv
 				}
@@ -365,7 +365,7 @@ func clusterUpgrade(c configv1client.Interface, dc dynamic.Interface, config *re
 			Version:  "v1",
 			Resource: "machineconfigpools",
 		})
-		pools, err := mcps.List(metav1.ListOptions{})
+		pools, err := mcps.List(context.Background(), metav1.ListOptions{})
 		if err != nil {
 			framework.Logf("error getting pools %v", err)
 			return false, nil
@@ -390,7 +390,7 @@ func clusterUpgrade(c configv1client.Interface, dc dynamic.Interface, config *re
 
 // TODO(runcom): drop this when MCO types are in openshift/api and we can use the typed client directly
 func IsPoolUpdated(dc dynamic.NamespaceableResourceInterface, name string) (bool, error) {
-	pool, err := dc.Get(name, metav1.GetOptions{})
+	pool, err := dc.Get(context.Background(), name, metav1.GetOptions{})
 	if err != nil {
 		framework.Logf("error getting pool %s: %v", name, err)
 		return false, nil
