@@ -8,31 +8,32 @@ import (
 	"strings"
 	"time"
 
-	"github.com/coreos/etcd/clientv3"
 	g "github.com/onsi/ginkgo"
 	o "github.com/onsi/gomega"
+	"go.etcd.io/etcd/clientv3"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	restclient "k8s.io/client-go/rest"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
+	e2eskipper "k8s.io/kubernetes/test/e2e/framework/skipper"
 
 	exutil "github.com/openshift/origin/test/extended/util"
 	"github.com/openshift/origin/test/extended/util/ibmcloud"
 )
 
-var _ = g.Describe("[Serial] API data in etcd", func() {
+var _ = g.Describe("[sig-api-machinery] API data in etcd", func() {
 	defer g.GinkgoRecover()
 
-	oc := exutil.NewCLI("etcd-storage-path", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("etcd-storage-path").AsAdmin()
 
-	_ = g.It("should be stored at the correct location and version for all resources", func() {
+	_ = g.It("should be stored at the correct location and version for all resources [Serial]", func() {
 		if e2e.TestContext.Provider == ibmcloud.ProviderName {
-			e2e.Skipf("IBM ROKS clusters run etcd outside of the cluster. Etcd cannot be accessed directly from within the cluster")
+			e2eskipper.Skipf("IBM ROKS clusters run etcd outside of the cluster. Etcd cannot be accessed directly from within the cluster")
 		}
 
 		ctx, cancel := context.WithCancel(context.Background())
-		cmd := exec.CommandContext(ctx, "oc", "port-forward", "service/etcd", ":2379", "-n", "openshift-etcd", "--config", exutil.KubeConfigPath())
+		cmd := exec.CommandContext(ctx, "oc", "port-forward", "service/etcd", ":2379", "-n", "openshift-etcd")
 
 		defer func() {
 			cancel()
@@ -45,8 +46,9 @@ var _ = g.Describe("[Serial] API data in etcd", func() {
 		o.Expect(cmd.Start()).NotTo(o.HaveOccurred())
 
 		scanner := bufio.NewScanner(stdOut)
-		o.Expect(scanner.Scan()).To(o.BeTrue())
+		scan := scanner.Scan()
 		o.Expect(scanner.Err()).NotTo(o.HaveOccurred())
+		o.Expect(scan).To(o.BeTrue())
 		output := scanner.Text()
 
 		port := strings.TrimSuffix(strings.TrimPrefix(output, "Forwarding from 127.0.0.1:"), " -> 2379")
@@ -54,9 +56,9 @@ var _ = g.Describe("[Serial] API data in etcd", func() {
 		o.Expect(err).NotTo(o.HaveOccurred(), "port forward output not in expected format: %s", output)
 
 		coreV1 := oc.AdminKubeClient().CoreV1()
-		etcdConfigMap, err := coreV1.ConfigMaps("openshift-config").Get("etcd-ca-bundle", metav1.GetOptions{})
+		etcdConfigMap, err := coreV1.ConfigMaps("openshift-config").Get(context.Background(), "etcd-ca-bundle", metav1.GetOptions{})
 		o.Expect(err).NotTo(o.HaveOccurred())
-		etcdSecret, err := coreV1.Secrets("openshift-config").Get("etcd-client", metav1.GetOptions{})
+		etcdSecret, err := coreV1.Secrets("openshift-config").Get(context.Background(), "etcd-client", metav1.GetOptions{})
 		o.Expect(err).NotTo(o.HaveOccurred())
 
 		tlsConfig, err := restclient.TLSConfigFor(&restclient.Config{
